#' @title Spatial datasets of trace elements.
#'
#' @description Spatial datasets of trace elements.
#'
#' @name obs
#' @format \code{obs}: A data frame of trace elements with 614 rows and 5 variables
#' @docType data
#' @author Yongze Song \email{yongze.song@curtin.edu.au}
#' @keywords dataset trace elements
"obs"


#' @title Spatial datasets of the second dimension variables of trace elements.
#'
#' @description Spatial datasets of the second dimension variables of trace elements.
#'
#' @name sample_vars_sda
#' @format \code{sample_vars_sda}: A list with 8 elements
#' @docType data
#' @author Yongze Song \email{yongze.song@curtin.edu.au}
#' @keywords dataset trace elements factors
"sample_vars_sda"


#' @title Spatial datasets of the first dimension variables of trace elements.
#'
#' @description Spatial datasets of the first dimension variables of trace elements.
#'
#' @name sample_vars_fda
#' @format \code{sample_vars_fda}: A list with 8 elements
#' @docType data
#' @author Yongze Song \email{yongze.song@curtin.edu.au}
#' @keywords dataset trace elements factors
"sample_vars_fda"

#' @title Spatial grid dataset.
#'
#' @description Spatial datasets of explanatory variables at a 500-m resolution.
#'
#' @name grids
#' @format \code{grids}: A data frame of explanatory variables with 68757 rows and 11 columns.
#' @docType data
#' @author Yongze Song \email{yongze.song@curtin.edu.au}
#' @keywords variables grids
"grids"
